<?php
namespace BrewPixel\BrewPress\Admin;

/**
 * Class Admin: The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @link       http://brewpixel.com
 * @since      1.0.0
 * @package    BrewPress
 * @subpackage BrewPixel\BrewPress\Admin
 * @author     Martin Goldie <martin@brewpixel.com>
 */
class Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $brewpress    The ID of this plugin.
	 */
	private $brewpress;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $brewpress       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $brewpress, $version ) {

		$this->brewpress = $brewpress;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->brewpress, realpath(dirname(plugin_dir_url( __FILE__ )
            . 'public/admin/css/brewpress-admin.css')), array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->brewpress, realpath(dirname(plugin_dir_url( __FILE__ )
            . 'public/admin/js/brewpress-admin.js')), array( 'jquery' ), $this->version, false );

	}
}
